package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcOutsource;

/**
 * 项目委外Service接口
 * 
 * @author cmc
 * @date 2024-09-19
 */
public interface ICmcOutsourceService 
{
    /**
     * 查询项目委外
     * 
     * @param outsourceId 项目委外主键
     * @return 项目委外
     */
    public CmcOutsource selectCmcOutsourceByOutsourceId(String outsourceId);

    /**
     * 查询项目委外列表
     * 
     * @param cmcOutsource 项目委外
     * @return 项目委外集合
     */
    public List<CmcOutsource> selectCmcOutsourceList(CmcOutsource cmcOutsource);

    /**
     * 新增项目委外
     * 
     * @param cmcOutsource 项目委外
     * @return 结果
     */
    public int insertCmcOutsource(CmcOutsource cmcOutsource);

    /**
     * 修改项目委外
     * 
     * @param cmcOutsource 项目委外
     * @return 结果
     */
    public int updateCmcOutsource(CmcOutsource cmcOutsource);

    /**
     * 批量删除项目委外
     * 
     * @param outsourceIds 需要删除的项目委外主键集合
     * @return 结果
     */
    public int deleteCmcOutsourceByOutsourceIds(String[] outsourceIds);

    /**
     * 删除项目委外信息
     * 
     * @param outsourceId 项目委外主键
     * @return 结果
     */
    public int deleteCmcOutsourceByOutsourceId(String outsourceId);
}
